@@ -25,7 +25,7 @@ use POSIX qw( SIGTERM WIFEXITED WEXITSTATUS WIFSIGNALED WTERMSIG );
 use Socket qw( sockaddr_family AF_UNIX );
 use Time::HiRes qw( time );
 
-our $VERSION = '0.48';
+our $VERSION = '0.49';
 
 # Abstract Units of Time
 use constant AUT => $ENV{TEST_QUICK_TIMERS} ? 0.1 : 1;
@@ -627,7 +627,7 @@ sub run_tests_idle
    is( $called, 2, 'unwatched deferral not called' );
 
    $id = $loop->watch_idle( when => 'later', code => sub { $called = 3 } );
-   my $timer_id = $loop->watch_time( delay => 5, code => sub {} );
+   my $timer_id = $loop->watch_time( after => 5, code => sub {} );
 
    $loop->loop_once( 1 );
 
